summaryrefslogtreecommitdiffstats
path: root/kmail/folderstorage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/folderstorage.h')
-rw-r--r--kmail/folderstorage.h45
1 files changed, 23 insertions, 22 deletions
diff --git a/kmail/folderstorage.h b/kmail/folderstorage.h
index b7effe08..ab58d4fd 100644
--- a/kmail/folderstorage.h
+++ b/kmail/folderstorage.h
@@ -22,11 +22,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -71,20 +71,21 @@ typedef TQValueList<TQ_UINT32> SerNumList;
*
* @section Accounts
* The accounts (of KMail) that are fed into the folder are
- * represented as the children of the folder. They are only stored here
+ * represented as the tqchildren of the folder. They are only stored here
* during runtime to have a reference for which accounts point to a
* specific folder.
*/
-class FolderStorage : public QObject
+class FolderStorage : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- /** Usually a parent is given. But in some cases there is no
- fitting parent object available. Then the name of the folder
+ /** Usually a tqparent is given. But in some cases there is no
+ fitting tqparent object available. Then the name of the folder
is used as the absolute path to the folder file. */
FolderStorage( KMFolder* folder, const char* name=0 );
virtual ~FolderStorage();
@@ -108,10 +109,10 @@ public:
/** Specify, that the folder can't contain mails. */
virtual void setNoContent(bool aNoContent);
- /** Returns, if the folder can't have children */
+ /** Returns, if the folder can't have tqchildren */
virtual bool noChildren() const { return mNoChildren; }
- /** Specify, that the folder can't have children */
+ /** Specify, that the folder can't have tqchildren */
virtual void setNoChildren( bool aNoChildren );
enum ChildrenState {
@@ -119,11 +120,11 @@ public:
HasNoChildren,
ChildrenUnknown
};
- /** Returns if the folder has children,
- * has no children or we don't know */
+ /** Returns if the folder has tqchildren,
+ * has no tqchildren or we don't know */
virtual ChildrenState hasChildren() const { return mHasChildren; }
- /** Specify if the folder has children */
+ /** Specify if the folder has tqchildren */
virtual void setHasChildren( ChildrenState state )
{ mHasChildren = state; }
@@ -158,7 +159,7 @@ public:
* for each derived KMFolder).
*/
virtual FolderJob* createJob( KMMessage *msg, FolderJob::JobType jt = FolderJob::tGetMessage,
- KMFolder *folder = 0, TQString partSpecifier = TQString::null,
+ KMFolder *folder = 0, TQString partSpecifier = TQString(),
const AttachmentStrategy *as = 0 ) const;
virtual FolderJob* createJob( TQPtrList<KMMessage>& msgList, const TQString& sets,
FolderJob::JobType jt = FolderJob::tGetMessage,
@@ -228,8 +229,8 @@ public:
virtual int moveMsg(TQPtrList<KMMessage>, int* index_return = 0);
/** Returns the index of the given message or -1 if not found. */
- virtual int find(const KMMsgBase* msg) const = 0;
- int find( const KMMessage * msg ) const;
+ virtual int tqfind(const KMMsgBase* msg) const = 0;
+ int tqfind( const KMMessage * msg ) const;
/** Number of messages in this folder. */
virtual int count(bool cache = false) const;
@@ -244,10 +245,10 @@ public:
* be reflected in the UI. */
virtual bool isCloseToQuota() const;
/** Called by KMMsgBase::seStatus when status of a message has changed
required to keep the number unread messages variable current. */
- virtual void msgStatusChanged( const KMMsgStatus oldStatus,
- const KMMsgStatus newStatus,
+ virtual void msgStatusChanged( const KMMsgtqStatus oldtqStatus,
+ const KMMsgtqStatus newtqStatus,
int idx);
/** Open folder for access.
@@ -324,7 +325,7 @@ public:
/** Change the dirty flag. */
void setDirty(bool f);
- /** Returns TRUE if the folder tqcontains deleted messages */
+ /** Returns TRUE if the folder contains deleted messages */
bool needsCompacting() const { return needsCompact; }
virtual void setNeedsCompacting(bool f) { needsCompact = f; }
@@ -363,10 +364,10 @@ public:
void deregisterFromMessageDict();
/** Set the status of the message at index @p idx to @p status. */
- virtual void seStatus(int idx, KMMsgStatus status, bool toggle=false);
+ virtual void setqStatus(int idx, KMMsgtqStatus status, bool toggle=false);
/** Set the status of the message(s) in the TQValueList @p ids to @p status. */
- virtual void seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
+ virtual void setqStatus(TQValueList<int>& ids, KMMsgtqStatus status, bool toggle=false);
void removeJobs();
@@ -581,7 +582,7 @@ friend class KMMsgDict;
/** Replaces the serial number for the message @p msg at index @p idx with
* @p sernum */
- void tqreplaceMsgSerNum( unsigned long sernum, KMMsgBase* msg, int idx );
+ void replaceMsgSerNum( unsigned long sernum, KMMsgBase* msg, int idx );
/** Called when serial numbers for a folder are tqinvalidated,
tqinvalidates/recreates data structures dependent on the
@@ -244,10 +245,10 @@ public:
* be reflected in the UI. */
virtual bool isCloseToQuota() const;
- /** Called by KMMsgBase::seStatus when status of a message has changed
+ /** Called by KMMsgBase::setqStatus when status of a message has changed
required to keep the number unread messages variable current. */